CardModel class

Constructors

CardModel({required Render render, required Map<String, dynamic> request, List<String>? questions})
CardModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
questions List<String>?
finalinherited
render → Render
finalinherited
request Map<String, dynamic>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity() → CardEntity
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited