LogoModel class

Constructors

LogoModel({String? blurhash, String? ticker})
LogoModel.fromJson(Map<String, dynamic> json)
factory

Properties

blurhash String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticker String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited