ZeedConfiguration class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
changeLang(
{String? lang}) → dynamic - Call this method to change the language
-
fetchStockImage(
{required String finasset}) → dynamic - Call this method to get the stock image
-
fetchStockList(
{List< String> ? stockList}) → dynamic - Call this method to fetch the stock list
-
init(
{required String apiKey, required String userId, required String clientId, String? lang, List< String> ? stockList}) → dynamic - Initialize this method first to pass the api values